@@ -13,13 +13,13 @@ from unittest.mock import MagicMock, Mock
 
 import nbformat
 import pytest
-import xmltodict
+import xmltodict  # type: ignore
 from ipython_genutils.py3compat import string_types
 from jupyter_client import KernelManager
 from jupyter_client.kernelspec import KernelSpecManager
-from nbconvert.filters import strip_ansi
+from nbconvert.filters import strip_ansi  # type: ignore
 from nbformat import NotebookNode
-from testpath import modified_env
+from testpath import modified_env  # type: ignore
 from traitlets import TraitError
 
 from .. import NotebookClient, execute
@@ -27,8 +27,11 @@ from ..exceptions import CellExecutionError
 from .base import NBClientTestsBase
 
 addr_pat = re.compile(r'0x[0-9a-f]{7,9}')
-ipython_input_pat = re.compile(r'<ipython-input-\d+-[0-9a-f]+>')
 current_dir = os.path.dirname(__file__)
+ipython_input_pat = re.compile(r'<ipython-input-\d+-[0-9a-f]+>')
+# Tracebacks look different in IPython 8,
+# see: https://github.com/ipython/ipython/blob/master/docs/source/whatsnew/version8.rst#traceback-improvements  # noqa
+ipython8_input_pat = re.compile(r'Input In \[\d+\],')
 
 
 class AsyncMock(Mock):
@@ -201,10 +204,11 @@ def normalize_output(output):
         if isinstance(value, string_types):
             output['data'][key] = normalize_base64(value)
     if 'traceback' in output:
-        tb = [
-            re.sub(ipython_input_pat, '<IPY-INPUT>', strip_ansi(line))
-            for line in output['traceback']
-        ]
+        tb = []
+        for line in output["traceback"]:
+            line = re.sub(ipython_input_pat, '<IPY-INPUT>', strip_ansi(line))
+            line = re.sub(ipython8_input_pat, '<IPY-INPUT>', strip_ansi(line))
+            tb.append(line)
         output['traceback'] = tb
 
     return output
@@ -408,7 +412,7 @@ def test_synchronous_setup_kernel():
     nb = nbformat.v4.new_notebook()
     executor = NotebookClient(nb)
     with executor.setup_kernel():
-        # Prove it initalized client
+        # Prove it initialized client
         assert executor.kc is not None
     # Prove it removed the client (and hopefully cleaned up)
     assert executor.kc is None
@@ -420,7 +424,7 @@ def test_startnewkernel_with_kernelmanager():
     executor = NotebookClient(nb, km=km)
     executor.start_new_kernel()
     kc = executor.start_new_kernel_client()
-    # prove it initalized client
+    # prove it initialized client
     assert kc is not None
     # since we are not using the setup_kernel context manager,
     # cleanup has to be done manually
